@@ -20,9 +20,9 @@ use Exporter q{import};
 our @EXPORT = qw(hook debug error htmlpage template template_depends
 	deptype add_depends pagespec_match pagespec_match_list bestlink
 	htmllink readfile writefile pagetype srcfile pagename
-	displaytime strftime_utf8 will_render gettext ngettext urlto targetpage
+	displaytime will_render gettext ngettext urlto targetpage
 	add_underlay pagetitle titlepage linkpage newpagefile
-	inject add_link add_autofile useragent
+	inject add_link add_autofile
 	%config %links %pagestate %wikistate %renderedfiles
 	%pagesources %destsources %typedlinks);
 our $VERSION = 3.00; # plugin interface version, next is ikiwiki version
@@ -118,22 +118,6 @@ sub getsetup () {
 		safe => 0,
 		rebuild => 0,
 	},
-	cgi_overload_delay => {
-		type => "string",
-		default => '',
-		example => "10",
-		description => "number of seconds to delay CGI requests when overloaded",
-		safe => 1,
-		rebuild => 0,
-	},
-	cgi_overload_message => {
-		type => "string",
-		default => '',
-		example => "Please wait",
-		description => "message to display when overloaded (may contain html)",
-		safe => 1,
-		rebuild => 0,
-	},
 	rcs => {
 		type => "string",
 		default => '',
@@ -253,8 +237,8 @@ sub getsetup () {
 	html5 => {
 		type => "boolean",
 		default => 0,
-		description => "generate HTML5?",
-		advanced => 0,
+		description => "generate HTML5? (experimental)",
+		advanced => 1,
 		safe => 1,
 		rebuild => 1,
 	},
@@ -321,9 +305,9 @@ sub getsetup () {
 		rebuild => 0,
 	},
 	umask => {
-		type => "string",
-		example => "public",
-		description => "force ikiwiki to use a particular umask (keywords public, group or private, or a number)",
+		type => "integer",
+		example => "022",
+		description => "force ikiwiki to use a particular umask",
 		advanced => 1,
 		safe => 0, # paranoia
 		rebuild => 0,
@@ -352,14 +336,6 @@ sub getsetup () {
 		safe => 0, # paranoia
 		rebuild => 0,
 	},
-	timezone => {
-		type => "string", 
-		default => "",
-		example => "US/Eastern",
-		description => "time zone name",
-		safe => 1,
-		rebuild => 1,
-	},
 	include => {
 		type => "string",
 		default => undef,
@@ -501,7 +477,7 @@ sub getsetup () {
 	},
 	setuptype => {
 		type => "internal",
-		default => "Yaml",
+		default => "Standard",
 		description => "perl class to use to dump setup file",
 		safe => 0,
 		rebuild => 0,
@@ -513,13 +489,6 @@ sub getsetup () {
 		safe => 0,
 		rebuild => 0,
 	},
-	cookiejar => {
-		type => "string",
-		default => { file => "$ENV{HOME}/.ikiwiki/cookies" },
-		description => "cookie control",
-		safe => 0, # hooks into perl module internals
-		rebuild => 0,
-	},
 }
 
 sub defaultconfig () {
@@ -528,6 +497,7 @@ sub defaultconfig () {
 	foreach my $key (keys %s) {
 		push @ret, $key, $s{$key}->{default};
 	}
+	use Data::Dumper;
 	return @ret;
 }
 
@@ -559,12 +529,6 @@ sub checkconfig () {
 			$ENV{$val}=$config{ENV}{$val};
 		}
 	}
-	if (defined $config{timezone} && length $config{timezone}) {
-		$ENV{TZ}=$config{timezone};
-	}
-	else {
-		$config{timezone}=$ENV{TZ};
-	}
 
 	if ($config{w3mmode}) {
 		eval q{use Cwd q{abs_path}};
@@ -610,23 +574,7 @@ sub checkconfig () {
 		unless exists $config{wikistatedir} && defined $config{wikistatedir};
 
 	if (defined $config{umask}) {
-		my $u = possibly_foolish_untaint($config{umask});
-
-		if ($u =~ m/^\d+$/) {
-			umask($u);
-		}
-		elsif ($u eq 'private') {
-			umask(077);
-		}
-		elsif ($u eq 'group') {
-			umask(027);
-		}
-		elsif ($u eq 'public') {
-			umask(022);
-		}
-		else {
-			error(sprintf(gettext("unsupported umask setting %s"), $u));
-		}
+		umask(possibly_foolish_untaint($config{umask}));
 	}
 
 	run_hooks(checkconfig => sub { shift->() });
@@ -862,23 +810,17 @@ sub srcfile ($;$) {
 	return (srcfile_stat(@_))[0];
 }
 
-sub add_literal_underlay ($) {
-	my $dir=shift;
-
-	if (! grep { $_ eq $dir } @{$config{underlaydirs}}) {
-		unshift @{$config{underlaydirs}}, $dir;
-	}
-}
-
 sub add_underlay ($) {
-	my $dir = shift;
+	my $dir=shift;
 
 	if ($dir !~ /^\//) {
 		$dir="$config{underlaydirbase}/$dir";
 	}
 
-	add_literal_underlay($dir);
-	# why does it return 1? we just don't know
+	if (! grep { $_ eq $dir } @{$config{underlaydirs}}) {
+		unshift @{$config{underlaydirs}}, $dir;
+	}
+
 	return 1;
 }
 
@@ -1065,7 +1007,7 @@ sub bestlink ($$) {
 sub isinlinableimage ($) {
 	my $file=shift;
 	
-	return $file =~ /\.(png|gif|jpg|jpeg|svg)$/i;
+	return $file =~ /\.(png|gif|jpg|jpeg)$/i;
 }
 
 sub pagetitle ($;$) {
@@ -1115,11 +1057,6 @@ sub cgiurl (@) {
 		join("&amp;", map $_."=".uri_escape_utf8($params{$_}), keys %params);
 }
 
-sub cgiurl_abs (@) {
-	eval q{use URI};
-	URI->new_abs(cgiurl(@_), $config{cgiurl});
-}
-
 sub baseurl (;$) {
 	my $page=shift;
 
@@ -1176,19 +1113,9 @@ sub formattime ($;$) {
 		$format=$config{timeformat};
 	}
 
-	return strftime_utf8($format, localtime($time));
-}
-
-my $strftime_encoding;
-sub strftime_utf8 {
 	# strftime doesn't know about encodings, so make sure
-	# its output is properly treated as utf8.
-	# Note that this does not handle utf-8 in the format string.
-	($strftime_encoding) = POSIX::setlocale(&POSIX::LC_TIME) =~ m#\.([^@]+)#
-		unless defined $strftime_encoding;
-	$strftime_encoding
-		? Encode::decode($strftime_encoding, POSIX::strftime(@_))
-		: POSIX::strftime(@_);
+	# its output is properly treated as utf8
+	return decode_utf8(POSIX::strftime($format, localtime($time)));
 }
 
 sub date_3339 ($) {
@@ -1235,7 +1162,7 @@ sub urlto ($;$$) {
 	}
 
 	if (! defined $from) {
-		my $u = $local_url || '';
+		my $u = $local_url;
 		$u =~ s{/$}{};
 		return $u.beautify_urlpath("/".$to);
 	}
@@ -1291,7 +1218,7 @@ sub htmllink ($$$;@) {
 				$cgilink = "<a href=\"".
 					cgiurl(
 						do => "create",
-						page => $link,
+						page => lc($link),
 						from => $lpage
 					)."\" rel=\"nofollow\">?</a>";
 			}
@@ -1440,21 +1367,16 @@ sub preprocess ($$$;$$) {
 			# consider it significant.
 			my @params;
 			while ($params =~ m{
-				(?:([-.\w]+)=)?		# 1: named parameter key?
+				(?:([-\w]+)=)?		# 1: named parameter key?
 				(?:
 					"""(.*?)"""	# 2: triple-quoted value
 				|
 					"([^"]*?)"	# 3: single-quoted value
 				|
-					'''(.*?)'''     # 4: triple-single-quote
-				|
-					<<([a-zA-Z]+)\n # 5: heredoc start
-					(.*?)\n\5	# 6: heredoc value
-				|
-					(\S+)		# 7: unquoted value
+					(\S+)		# 4: unquoted value
 				)
 				(?:\s+|$)		# delimiter to next param
-			}msgx) {
+			}sgx) {
 				my $key=$1;
 				my $val;
 				if (defined $2) {
@@ -1469,12 +1391,6 @@ sub preprocess ($$$;$$) {
 				elsif (defined $4) {
 					$val=$4;
 				}
-				elsif (defined $7) {
-					$val=$7;
-				}
-				elsif (defined $6) {
-					$val=$6;
-				}
 
 				if (defined $key) {
 					push @params, $key, $val;
@@ -1537,17 +1453,12 @@ sub preprocess ($$$;$$) {
 			(		# 4: the parameters..
 				\s+	# Must have space if parameters present
 				(?:
-					(?:[-.\w]+=)?		# named parameter key?
+					(?:[-\w]+=)?		# named parameter key?
 					(?:
 						""".*?"""	# triple-quoted value
 						|
 						"[^"]*?"	# single-quoted value
 						|
-						'''.*?'''	# triple-single-quote
-						|
-						<<([a-zA-Z]+)\n # 5: heredoc start
-						(?:.*?)\n\5	# heredoc value
-						|
 						[^"\s\]]+	# unquoted value
 					)
 					\s*			# whitespace or end
@@ -1565,17 +1476,12 @@ sub preprocess ($$$;$$) {
 			\s+
 			(		# 4: the parameters..
 				(?:
-					(?:[-.\w]+=)?		# named parameter key?
+					(?:[-\w]+=)?		# named parameter key?
 					(?:
 						""".*?"""	# triple-quoted value
 						|
 						"[^"]*?"	# single-quoted value
 						|
-						'''.*?'''       # triple-single-quote
-						|
-						<<([a-zA-Z]+)\n # 5: heredoc start
-						(?:.*?)\n\5	# heredoc value
-						|
 						[^"\s\]]+	# unquoted value
 					)
 					\s*			# whitespace or end
@@ -2281,13 +2187,6 @@ sub add_autofile ($$$) {
 	$autofiles{$file}{generator}=$generator;
 }
 
-sub useragent () {
-	return LWP::UserAgent->new(
-		cookie_jar => $config{cookiejar},
-		env_proxy => 1,		# respect proxy env vars
-	);
-}
-
 sub sortspec_translate ($$) {
 	my $spec = shift;
 	my $reverse = shift;
@@ -2692,14 +2591,8 @@ sub match_link ($$;@) {
 }
 
 sub match_backlink ($$;@) {
-	my $page=shift;
-	my $testpage=shift;
-	my %params=@_;
-	if ($testpage eq '.') {
-		$testpage = $params{'location'}
-	}
-	my $ret=match_link($testpage, $page, @_);
-	$ret->influences($testpage => $IkiWiki::DEPEND_LINKS);
+	my $ret=match_link($_[1], $_[0], @_);
+	$ret->influences($_[1] => $IkiWiki::DEPEND_LINKS);
 	return $ret;
 }
 
@@ -2790,12 +2683,12 @@ sub match_user ($$;@) {
 	my $user=shift;
 	my %params=@_;
 	
+	my $regexp=IkiWiki::glob2re($user);
+	
 	if (! exists $params{user}) {
 		return IkiWiki::ErrorReason->new("no user specified");
 	}
 
-	my $regexp=IkiWiki::glob2re($user);
-	
 	if (defined $params{user} && $params{user}=~$regexp) {
 		return IkiWiki::SuccessReason->new("user is $user");
 	}
@@ -2835,10 +2728,8 @@ sub match_ip ($$;@) {
 	if (! exists $params{ip}) {
 		return IkiWiki::ErrorReason->new("no IP specified");
 	}
-	
-	my $regexp=IkiWiki::glob2re(lc $ip);
 
-	if (defined $params{ip} && lc $params{ip}=~$regexp) {
+	if (defined $params{ip} && lc $params{ip} eq lc $ip) {
 		return IkiWiki::SuccessReason->new("IP is $ip");
 	}
 	else {
@@ -2861,7 +2752,6 @@ sub cmp_title {
 	IkiWiki::pagetitle(IkiWiki::basename($b))
 }
 
-sub cmp_path { IkiWiki::pagetitle($a) cmp IkiWiki::pagetitle($b) }
 sub cmp_mtime { $IkiWiki::pagemtime{$b} <=> $IkiWiki::pagemtime{$a} }
 sub cmp_age { $IkiWiki::pagectime{$b} <=> $IkiWiki::pagectime{$a} }
 
