@@ -12,7 +12,7 @@ use Encode;
 sub printheader ($) {
 	my $session=shift;
 	
-	if (($ENV{HTTPS} && lc $ENV{HTTPS} ne "off") || $config{sslcookie}) {
+	if ($ENV{HTTPS} || $config{sslcookie}) {
 		print $session->header(-charset => 'utf-8',
 			-cookie => $session->cookie(-httponly => 1, -secure => 1));
 	}
@@ -79,7 +79,7 @@ sub cgitemplate ($$$;@) {
 		title => $title,
 		wikiname => $config{wikiname},
 		content => $content,
-		baseurl => urlabs(baseurl(), $topurl),
+		baseurl => urlabs(urlto(""), $topurl),
 		html5 => $config{html5},
 		%params,
 	);
@@ -131,7 +131,7 @@ sub needsignin ($$) {
 
 	if (! defined $session->param("name") ||
 	    ! userinfo_get($session->param("name"), "regdate")) {
-		$session->param(postsignin => $q->query_string);
+		$session->param(postsignin => $ENV{QUERY_STRING});
 		cgi_signin($q, $session);
 		cgi_savesession($session);
 		exit;
@@ -429,7 +429,7 @@ sub cgi (;$$) {
 			# userinfo db.
 			if (! userinfo_get($session->param("name"), "regdate")) {
 				userinfo_setall($session->param("name"), {
-					email => defined $session->param("email") ? $session->param("email") : "",
+					email => "",
 					password => "",
 					regdate => time,
 				}) || error("failed adding user");
