@@ -9,6 +9,7 @@ use warnings;
 use strict;
 use IkiWiki 3.00;
 use Encode;
+use POSIX qw(strftime);
 
 use constant PREVIEW => "Preview";
 use constant POST_COMMENT => "Post comment";
@@ -20,8 +21,7 @@ my %commentstate;
 sub import {
 	hook(type => "checkconfig", id => 'comments',  call => \&checkconfig);
 	hook(type => "getsetup", id => 'comments',  call => \&getsetup);
-	hook(type => "preprocess", id => 'comment', call => \&preprocess,
-		scan => 1);
+	hook(type => "preprocess", id => 'comment', call => \&preprocess);
 	hook(type => "preprocess", id => 'commentmoderation', call => \&preprocess_moderation);
 	# here for backwards compatability with old comments
 	hook(type => "preprocess", id => '_comment', call => \&preprocess);
@@ -90,15 +90,6 @@ sub getsetup () {
 			safe => 0,
 			rebuild => 0,
 		},
-		comments_allowformats => {
-			type => 'string',
-			default => '',
-			example => 'mdwn txt',
-			description => 'Restrict formats for comments to (no restriction if empty)',
-			safe => 1,
-			rebuild => 0,
-		},
-
 }
 
 sub checkconfig () {
@@ -110,8 +101,6 @@ sub checkconfig () {
 		unless defined $config{comments_closed_pagespec};
 	$config{comments_pagename} = 'comment_'
 		unless defined $config{comments_pagename};
-	$config{comments_allowformats} = ''
-		unless defined $config{comments_allowformats};
 }
 
 sub htmlize {
@@ -139,18 +128,12 @@ sub safeurl ($) {
 	}
 }
 
-sub isallowed ($) {
-    my $format = shift;
-    return ! $config{comments_allowformats} || $config{comments_allowformats} =~ /\b$format\b/;
-}
-
 sub preprocess {
 	my %params = @_;
 	my $page = $params{page};
 
 	my $format = $params{format};
-	if (defined $format && (! exists $IkiWiki::hooks{htmlize}{$format} ||
-				! isallowed($format))) {
+	if (defined $format && ! exists $IkiWiki::hooks{htmlize}{$format}) {
 		error(sprintf(gettext("unsupported page format %s"), $format));
 	}
 
@@ -160,28 +143,23 @@ sub preprocess {
 	}
 	$content =~ s/\\"/"/g;
 
-	if (defined wantarray) {
-		if ($config{comments_allowdirectives}) {
-			$content = IkiWiki::preprocess($page, $params{destpage},
-				$content);
-		}
-
-		# no need to bother with htmlize if it's just HTML
-		$content = IkiWiki::htmlize($page, $params{destpage}, $format, $content)
-			if defined $format;
-
-		IkiWiki::run_hooks(sanitize => sub {
-			$content = shift->(
-				page => $page,
-				destpage => $params{destpage},
-				content => $content,
-			);
-		});
-	}
-	else {
-		IkiWiki::preprocess($page, $params{destpage}, $content, 1);
+	if ($config{comments_allowdirectives}) {
+		$content = IkiWiki::preprocess($page, $params{destpage},
+			$content);
 	}
 
+	# no need to bother with htmlize if it's just HTML
+	$content = IkiWiki::htmlize($page, $params{destpage}, $format, $content)
+		if defined $format;
+
+	IkiWiki::run_hooks(sanitize => sub {
+		$content = shift->(
+			page => $page,
+			destpage => $params{destpage},
+			content => $content,
+		);
+	});
+
 	# set metadata, possibly overriding [[!meta]] directives from the
 	# comment itself
 
@@ -222,7 +200,6 @@ sub preprocess {
 	$commentstate{$page}{commentip} = $commentip;
 	$commentstate{$page}{commentauthor} = $commentauthor;
 	$commentstate{$page}{commentauthorurl} = $commentauthorurl;
-	$commentstate{$page}{commentauthoravatar} = $params{avatar};
 	if (! defined $pagestate{$page}{meta}{author}) {
 		$pagestate{$page}{meta}{author} = $commentauthor;
 	}
@@ -239,7 +216,7 @@ sub preprocess {
 			my $url=$params{url};
 
 			eval q{use URI::Heuristic}; 
-			if (! $@) {
+		  	if (! $@) {
 				$url=URI::Heuristic::uf_uristr($url);
 			}
 
@@ -318,8 +295,7 @@ sub editcomment ($$) {
 
 	my @buttons = (POST_COMMENT, PREVIEW, CANCEL);
 	my $form = CGI::FormBuilder->new(
-		fields => [qw{do sid page subject editcontent type author
-			email url subscribe anonsubscribe}],
+		fields => [qw{do sid page subject editcontent type author url}],
 		charset => 'utf-8',
 		method => 'POST',
 		required => [qw{editcontent}],
@@ -349,7 +325,7 @@ sub editcomment ($$) {
 
 	my @page_types;
 	if (exists $IkiWiki::hooks{htmlize}) {
-		foreach my $key (grep { !/^_/ && isallowed($_) } keys %{$IkiWiki::hooks{htmlize}}) {
+		foreach my $key (grep { !/^_/ } keys %{$IkiWiki::hooks{htmlize}}) {
 			push @page_types, [$key, $IkiWiki::hooks{htmlize}{$key}{longname} || $key];
 		}
 	}
@@ -364,35 +340,18 @@ sub editcomment ($$) {
 	$form->field(name => "type", value => $type, force => 1,
 		type => 'select', options => \@page_types);
 
-	my $username=$session->param('name');
-	$form->tmpl_param(username => $username);
-		
-	$form->field(name => "subscribe", type => 'hidden');
-	$form->field(name => "anonsubscribe", type => 'hidden');
-	if (IkiWiki::Plugin::notifyemail->can("subscribe")) {
-		if (defined $username) {
-			$form->field(name => "subscribe", type => "checkbox",
-				options => [gettext("email replies to me")]);
-		}
-		elsif (IkiWiki::Plugin::passwordauth->can("anonuser")) {
-			$form->field(name => "anonsubscribe", type => "checkbox",
-				options => [gettext("email replies to me")]);
-		}
-	}
+	$form->tmpl_param(username => $session->param('name'));
 
 	if ($config{comments_allowauthor} and
 	    ! defined $session->param('name')) {
 		$form->tmpl_param(allowauthor => 1);
 		$form->field(name => 'author', type => 'text', size => '40');
-		$form->field(name => 'email', type => 'text', size => '40');
 		$form->field(name => 'url', type => 'text', size => '40');
 	}
 	else {
 		$form->tmpl_param(allowauthor => 0);
 		$form->field(name => 'author', type => 'hidden', value => '',
 			force => 1);
-		$form->field(name => 'email', type => 'hidden', value => '',
-			force => 1);
 		$form->field(name => 'url', type => 'hidden', value => '',
 			force => 1);
 	}
@@ -460,7 +419,10 @@ sub editcomment ($$) {
 		$content .= " nickname=\"$nickname\"\n";
 	}
 	elsif (defined $session->remote_addr()) {
-		$content .= " ip=\"".$session->remote_addr()."\"\n";
+		my $ip = $session->remote_addr();
+		if ($ip =~ m/^([.0-9]+)$/) {
+			$content .= " ip=\"$1\"\n";
+		}
 	}
 
 	if ($config{comments_allowauthor}) {
@@ -476,12 +438,6 @@ sub editcomment ($$) {
 		}
 	}
 
-	my $avatar=getavatar($session->param('name'));
-	if (defined $avatar && length $avatar) {
-		$avatar =~ s/"/&quot;/g;
-		$content .= " avatar=\"$avatar\"\n";
-	}
-
 	my $subject = $form->field('subject');
 	if (defined $subject && length $subject) {
 		$subject =~ s/"/&quot;/g;
@@ -491,7 +447,7 @@ sub editcomment ($$) {
 	}
 	$content .= " subject=\"$subject\"\n";
 
-	$content .= " date=\"" . strftime_utf8('%Y-%m-%dT%H:%M:%SZ', gmtime) . "\"\n";
+	$content .= " date=\"" . decode_utf8(strftime('%Y-%m-%dT%H:%M:%SZ', gmtime)) . "\"\n";
 
 	my $editcontent = $form->field('editcontent');
 	$editcontent="" if ! defined $editcontent;
@@ -522,20 +478,6 @@ sub editcomment ($$) {
 
 	if ($form->submitted eq POST_COMMENT && $form->validate) {
 		IkiWiki::checksessionexpiry($cgi, $session);
-
-		if (IkiWiki::Plugin::notifyemail->can("subscribe")) {
-			my $subspec="comment($page)";
-			if (defined $username &&
-			    length $form->field("subscribe")) {
-				IkiWiki::Plugin::notifyemail::subscribe(
-					$username, $subspec);
-			}
-			elsif (length $form->field("email") &&
-			       length $form->field("anonsubscribe")) {
-				IkiWiki::Plugin::notifyemail::anonsubscribe(
-					$form->field("email"), $subspec);
-			}
-		}
 		
 		$postcomment=1;
 		my $ok=IkiWiki::check_content(content => $form->field('editcontent'),
@@ -619,32 +561,6 @@ sub editcomment ($$) {
 	exit;
 }
 
-sub getavatar ($) {
-	my $user=shift;
-	return undef unless defined $user;
-
-	my $avatar;
-	eval q{use Libravatar::URL};
-	if (! $@) {
-		my $oiduser = eval { IkiWiki::openiduser($user) };
-		my $https=defined $config{url} && $config{url}=~/^https:/;
-
-		if (defined $oiduser) {
-			eval {
-				$avatar = libravatar_url(openid => $user, https => $https);
-			}
-		}
-		if (! defined $avatar &&
-		    (my $email = IkiWiki::userinfo_get($user, 'email'))) {
-			eval {
-				$avatar = libravatar_url(email => $email, https => $https);
-			}
-		}
-	}
-	return $avatar;
-}
-
-
 sub commentmoderation ($$) {
 	my $cgi=shift;
 	my $session=shift;
@@ -679,11 +595,9 @@ sub commentmoderation ($$) {
 
 				my $page=IkiWiki::dirname($f);
 				my $file="$config{srcdir}/$f";
-				my $filedir=$config{srcdir};
 				if (! -e $file) {
 					# old location
 					$file="$config{wikistatedir}/comments_pending/".$f;
-					$filedir="$config{wikistatedir}/comments_pending";
 				}
 
 				if ($action eq 'Accept') {
@@ -698,7 +612,7 @@ sub commentmoderation ($$) {
 				}
 
 				require IkiWiki::Render;
-				IkiWiki::prune($file, $filedir);
+				IkiWiki::prune($file);
 			}
 		}
 
@@ -841,8 +755,10 @@ sub previewcomment ($$$) {
 sub commentsshown ($) {
 	my $page=shift;
 
-	return pagespec_match($page, $config{comments_pagespec},
-		location => $page);
+	return ! pagespec_match($page, "comment(*)",
+	                        location => $page) &&
+	       pagespec_match($page, $config{comments_pagespec},
+	                      location => $page);
 }
 
 sub commentsopen ($) {
@@ -869,7 +785,7 @@ sub pagetemplate (@) {
 		my $comments = undef;
 		if ($shown) {
 			$comments = IkiWiki::preprocess_inline(
-				pages => "comment($page) and !comment($page/*)",
+				pages => "comment($page)",
 				template => 'comment',
 				show => 0,
 				reverse => 'yes',
@@ -960,11 +876,6 @@ sub pagetemplate (@) {
 			$commentstate{$page}{commentauthorurl});
 	}
 
-	if ($template->query(name => 'commentauthoravatar')) {
-		$template->param(commentauthoravatar =>
-			$commentstate{$page}{commentauthoravatar});
-	}
-
 	if ($template->query(name => 'removeurl') &&
 	    IkiWiki::Plugin::remove->can("check_canremove") &&
 	    length $config{cgiurl}) {
