@@ -3,7 +3,6 @@ package IkiWiki::Plugin::darcs;
 
 use warnings;
 use strict;
-use URI::Escape q{uri_escape_utf8};
 use IkiWiki;
 
 sub import {
@@ -337,8 +336,7 @@ sub rcs_recentchanges ($) {
 
 		foreach my $f (@files) {
 			my $d = defined $config{'diffurl'} ? $config{'diffurl'} : "";
-			my $ef = uri_escape_utf8($f);
-			$d =~ s/\[\[file\]\]/$ef/go;
+			$d =~ s/\[\[file\]\]/$f/go;
 			$d =~ s/\[\[hash\]\]/$hash/go;
 
 			push @pg, {
@@ -379,8 +377,7 @@ sub rcs_diff ($;$) {
 	my $rev=shift;
 	my $maxlines=shift;
 	my @lines;
-	my $repodir=$config{srcdir};
-	foreach my $line (`darcs diff --repodir  $repodir --match 'hash $rev'`) {
+	foreach my $line (silentsystem("darcs", "diff", "--match", "hash ".$rev)) {
 		if (@lines || $line=~/^diff/) {
 			last if defined $maxlines && @lines == $maxlines;
 			push @lines, $line."\n";
