@@ -64,11 +64,10 @@ sub preprocess (@) {
 
 	my $dir = $params{page};
 	my $base = IkiWiki::basename($file);
-	my $issvg = $base=~s/\.svg$/.png/i;
 
 	eval q{use Image::Magick};
 	error gettext("Image::Magick is not installed") if $@;
-	my $im = Image::Magick->new($issvg ? (magick => "png") : ());
+	my $im = Image::Magick->new;
 	my $imglink;
 	my $r = $im->Read($srcfile);
 	error sprintf(gettext("failed to read %s: %s"), $file, $r) if $r;
@@ -118,6 +117,7 @@ sub preprocess (@) {
 				error sprintf(gettext("failed to read %s: %s"), $outfile, $r) if $r;
 			}
 			else {
+				($dwidth, $dheight)=($w, $h);
 				$r = $im->Resize(geometry => "${w}x${h}");
 				error sprintf(gettext("failed to resize: %s"), $r) if $r;
 
@@ -131,10 +131,9 @@ sub preprocess (@) {
 					$imglink = $file;
 				}
 			}
-
-			# always get the true size of the resized image
-			$dwidth  = $im->Get("width"); 
-			$dheight = $im->Get("height");
+			
+			$dwidth = $im->Get("width") unless defined $dwidth;
+			$dheight = $im->Get("height") unless defined $dheight;
 		}
 	}
 	else {
