@@ -19,14 +19,14 @@ sub import {
 	hook(type => "checkconfig", id => "inline", call => \&checkconfig);
 	hook(type => "sessioncgi", id => "inline", call => \&sessioncgi);
 	hook(type => "preprocess", id => "inline", 
-		call => \&IkiWiki::preprocess_inline, scan => 1);
+		call => \&IkiWiki::preprocess_inline);
 	hook(type => "pagetemplate", id => "inline",
 		call => \&IkiWiki::pagetemplate_inline);
 	hook(type => "format", id => "inline", call => \&format, first => 1);
 	# Hook to change to do pinging since it's called late.
 	# This ensures each page only pings once and prevents slow
 	# pings interrupting page builds.
-	hook(type => "rendered", id => "inline", call => \&IkiWiki::pingurl);
+	hook(type => "change", id => "inline", call => \&IkiWiki::pingurl);
 }
 
 sub getopt () {
@@ -155,23 +155,6 @@ sub preprocess_inline (@) {
 	if (! exists $params{pages} && ! exists $params{pagenames}) {
 		error gettext("missing pages parameter");
 	}
-
-	if (! defined wantarray) {
-		# Running in scan mode: only do the essentials
-
-		if (yesno($params{trail}) && IkiWiki::Plugin::trail->can("preprocess_trailitems")) {
-			# default to sorting age, the same as inline itself,
-			# but let the params override that
-			IkiWiki::Plugin::trail::preprocess_trailitems(sort => 'age', %params);
-		}
-
-		return;
-	}
-
-	if (yesno($params{trail}) && IkiWiki::Plugin::trail->can("preprocess_trailitems")) {
-		scalar IkiWiki::Plugin::trail::preprocess_trailitems(sort => 'age', %params);
-	}
-
 	my $raw=yesno($params{raw});
 	my $archive=yesno($params{archive});
 	my $rss=(($config{rss} || $config{allowrss}) && exists $params{rss}) ? yesno($params{rss}) : $config{rss};
@@ -211,7 +194,8 @@ sub preprocess_inline (@) {
 			}
 		}
 
-		@list = split ' ', $params{pagenames};
+		@list = map { bestlink($params{page}, $_) }
+		        split ' ', $params{pagenames};
 
 		if (yesno($params{reverse})) {
 			@list=reverse(@list);
@@ -220,8 +204,6 @@ sub preprocess_inline (@) {
 		foreach my $p (@list) {
 			add_depends($params{page}, $p, deptype($quick ? "presence" : "content"));
 		}
-
-		@list = grep { exists $pagesources{$_} } @list;
 	}
 	else {
 		my $num=0;
@@ -347,10 +329,6 @@ sub preprocess_inline (@) {
 			$formtemplate->param(postformtext =>
 				gettext("Add a new post titled:"));
 		}
-		if (exists $params{id}) {
-			$formtemplate->param(postformid =>
-				$params{id});
-		}
 		$ret.=$formtemplate->output;
 	    	
 		# The post form includes the feed buttons, so
@@ -368,9 +346,6 @@ sub preprocess_inline (@) {
 			$linktemplate->param(atomurl => $atomurl);
 			$linktemplate->param(atomdesc => $atomdesc);
 		}
-		if (exists $params{id}) {
-			$linktemplate->param(id => $params{id});
-		}
 		$ret.=$linktemplate->output;
 	}
 	
@@ -465,7 +440,7 @@ sub preprocess_inline (@) {
 			if (! $params{preview}) {
 				writefile($rssp, $config{destdir},
 					genfeed("rss",
-						$config{url}."/".$rssp, $desc, $params{guid}, $params{page}, @feedlist));
+						$config{url}."/".$rssp, $desc, $params{guid}, $params{destpage}, @feedlist));
 				$toping{$params{destpage}}=1 unless $config{rebuild};
 				$feedlinks{$params{destpage}}.=qq{<link rel="alternate" type="application/rss+xml" title="$rssdesc" href="$rssurl" />};
 			}
@@ -475,7 +450,7 @@ sub preprocess_inline (@) {
 			will_render($params{destpage}, $atomp);
 			if (! $params{preview}) {
 				writefile($atomp, $config{destdir},
-					genfeed("atom", $config{url}."/".$atomp, $desc, $params{guid}, $params{page}, @feedlist));
+					genfeed("atom", $config{url}."/".$atomp, $desc, $params{guid}, $params{destpage}, @feedlist));
 				$toping{$params{destpage}}=1 unless $config{rebuild};
 				$feedlinks{$params{destpage}}.=qq{<link rel="alternate" type="application/atom+xml" title="$atomdesc" href="$atomurl" />};
 			}
@@ -524,7 +499,7 @@ sub get_inline_content ($$) {
 		if (isinternal($page)) {
 			# make inlined text of internal pages searchable
 			run_hooks(indexhtml => sub {
-				shift->(page => $page, destpage => $destpage,
+				shift->(page => $page, destpage => $page,
 					content => $ret);
 			});
 		}
@@ -582,15 +557,13 @@ sub absolute_urls ($$) {
 				next unless $v_offset; # 0 v_offset means no value
 				my $v = substr($text, $v_offset, $v_len);
 				$v =~ s/^([\'\"])(.*)\1$/$2/;
-				eval q{use HTML::Entities};
-				my $dv = decode_entities($v);
-				if ($dv=~/^#/) {
+				if ($v=~/^#/) {
 					$v=$baseurl.$v; # anchor
 				}
-				elsif ($dv=~/^(?!\w+:)[^\/]/) {
+				elsif ($v=~/^(?!\w+:)[^\/]/) {
 					$v=$url.$v; # relative url
 				}
-				elsif ($dv=~/^\//) {
+				elsif ($v=~/^\//) {
 					if (! defined $urltop) {
 						# what is the non path part of the url?
 						my $top_uri = URI->new($url);
@@ -611,26 +584,6 @@ sub absolute_urls ($$) {
 	return $ret;
 }
 
-sub genenclosure {
-	my $itemtemplate=shift;
-	my $url=shift;
-	my $file=shift;
-
-	return unless $itemtemplate->query(name => "enclosure");
-
-	my $size=(srcfile_stat($file))[8];
-	my $mime="unknown";
-	eval q{use File::MimeInfo};
-	if (! $@) {
-		$mime = mimetype($file);
-	}
-	$itemtemplate->param(
-		enclosure => $url,
-		type => $mime,
-		length => $size,
-	);
-}
-
 sub genfeed ($$$$$@) {
 	my $feedtype=shift;
 	my $feedurl=shift;
@@ -647,7 +600,6 @@ sub genfeed ($$$$$@) {
 	foreach my $p (@pages) {
 		my $u=URI->new(encode_utf8(urlto($p, "", 1)));
 		my $pcontent = absolute_urls(get_inline_content($p, $page), $url);
-		my $fancy_enclosure_seen = 0;
 
 		$itemtemplate->param(
 			title => pagetitle(basename($p)),
@@ -669,23 +621,32 @@ sub genfeed ($$$$$@) {
 				$itemtemplate->param(mdate_822 => date_822($pagestate{$p}{meta}{updated}));
 				$itemtemplate->param(mdate_3339 => date_3339($pagestate{$p}{meta}{updated}));
 			}
+		}
 
-			if (exists $pagestate{$p}{meta}{enclosure}) {
-				my $absurl = $pagestate{$p}{meta}{enclosure};
-				my $file = $pagestate{$p}{meta}{enclosurefile};
-				genenclosure($itemtemplate, $absurl, $file);
-				$fancy_enclosure_seen = 1;
+		if ($itemtemplate->query(name => "enclosure")) {
+			my $file=$pagesources{$p};
+			my $type=pagetype($file);
+			if (defined $type) {
+				$itemtemplate->param(content => $pcontent);
+			}
+			else {
+				my $size=(srcfile_stat($file))[8];
+				my $mime="unknown";
+				eval q{use File::MimeInfo};
+				if (! $@) {
+					$mime = mimetype($file);
+				}
+				$itemtemplate->param(
+					enclosure => $u,
+					type => $mime,
+					length => $size,
+				);
 			}
 		}
-
-		my $file=$pagesources{$p};
-		unless ($fancy_enclosure_seen || defined(pagetype($file))) {
-			genenclosure($itemtemplate, $u, $file);
-			$itemtemplate->param(simplepodcast => 1);
+		else {
+			$itemtemplate->param(content => $pcontent);
 		}
 
-		$itemtemplate->param(content => $pcontent);
-
 		run_hooks(pagetemplate => sub {
 			shift->(page => $p, destpage => $page,
 				template => $itemtemplate);
@@ -706,8 +667,8 @@ sub genfeed ($$$$$@) {
 		feeddesc => $feeddesc,
 		guid => $guid,
 		feeddate => date_3339($lasttime),
-		feeddate_822 => date_822($lasttime),
 		feedurl => $feedurl,
+		version => $IkiWiki::version,
 	);
 	run_hooks(pagetemplate => sub {
 		shift->(page => $page, destpage => $page,
