@@ -107,12 +107,12 @@ sub preprocess (@) {
 		# fallthrough
 	}
 	elsif ($key eq 'license') {
-		push @{$metaheaders{$page}}, '<link rel="license" href="#pagelicense" />';
+		push @{$metaheaders{$page}}, '<link rel="license" href="#page_license" />';
 		$pagestate{$page}{meta}{license}=$value;
 		return "";
 	}
 	elsif ($key eq 'copyright') {
-		push @{$metaheaders{$page}}, '<link rel="copyright" href="#pagecopyright" />';
+		push @{$metaheaders{$page}}, '<link rel="copyright" href="#page_copyright" />';
 		$pagestate{$page}{meta}{copyright}=$value;
 		return "";
 	}
@@ -121,18 +121,6 @@ sub preprocess (@) {
 		add_link($page, $value);
 		return "";
 	}
-	elsif ($key eq 'enclosure') {
-		my $link=bestlink($page, $value);
-		if (! length $link) {
-			error gettext("enclosure not found")
-		}
-		add_depends($page, $link, deptype("presence"));
-
-		$value=urlto($link, $page, 1);
-		$pagestate{$page}{meta}{enclosure}=$value;
-		$pagestate{$page}{meta}{enclosurefile}=$link;
-		# fallthrough
-	}
 	elsif ($key eq 'author') {
 		$pagestate{$page}{meta}{author}=$value;
 		if (exists $params{sortas}) {
@@ -186,21 +174,10 @@ sub preprocess (@) {
 		if (! length $stylesheet) {
 			error gettext("stylesheet not found")
 		}
-		push @{$metaheaders{$page}}, scrub('<link href="'.urlto($stylesheet, $page).
+		push @{$metaheaders{$page}}, '<link href="'.urlto($stylesheet, $page).
 			'" rel="'.encode_entities($rel).
 			'" title="'.encode_entities($title).
-			"\" type=\"text/css\" />", $page, $destpage);
-	}
-	elsif ($key eq 'script') {
-		my $defer=exists $params{defer} ? ' defer="defer"' : '';
-		my $async=exists $params{async} ? ' async="async"' : '';
-		my $js=bestlink($page, $value.".js");
-		if (! length $js) {
-			error gettext("script not found");
-		}
-		push @{$metaheaders{$page}}, scrub('<script src="'.urlto($js, $page).
-			'"' . $defer . $async . ' type="text/javascript"></script>',
-			$page, $destpage);
+			"\" type=\"text/css\" />";
 	}
 	elsif ($key eq 'openid') {
 		my $delegate=0; # both by default
@@ -229,13 +206,6 @@ sub preprocess (@) {
 				'content="'.encode_entities($url).'" />';
 		}
 	}
-	elsif ($key eq 'foaf') {
-		if (safeurl($value)) {
-			push @{$metaheaders{$page}}, '<link rel="meta" '.
-				'type="application/rdf+xml" title="FOAF" '.
-				'href="'.encode_entities($value).'" />';
-		}
-	}
 	elsif ($key eq 'redir') {
 		return "" if $page ne $destpage;
 		my $safe=0;
@@ -287,23 +257,17 @@ sub preprocess (@) {
 		push @{$metaheaders{$page}}, '<meta name="robots"'.
 			' content="'.encode_entities($value).'" />';
 	}
-	elsif ($key eq 'description' || $key eq 'author') {
-		push @{$metaheaders{$page}}, '<meta name="'.$key.
+	elsif ($key eq 'description') {
+		push @{$metaheaders{$page}}, '<meta name="'.
+			encode_entities($key).
 			'" content="'.encode_entities($value).'" />';
 	}
 	elsif ($key eq 'name') {
-		push @{$metaheaders{$page}}, scrub('<meta name="'.
+		push @{$metaheaders{$page}}, scrub('<meta '.$key.'="'.
 			encode_entities($value).
 			join(' ', map { "$_=\"$params{$_}\"" } keys %params).
 			' />', $page, $destpage);
 	}
-	elsif ($key eq 'keywords') {
-		# Make sure the keyword string is safe: only allow alphanumeric
-		# characters, space and comma and strip the rest.
-		$value =~ s/[^[:alnum:], ]+//g;
-		push @{$metaheaders{$page}}, '<meta name="keywords"'.
-			' content="'.encode_entities($value).'" />';
-	}
 	else {
 		push @{$metaheaders{$page}}, scrub('<meta name="'.
 			encode_entities($key).'" content="'.
@@ -325,30 +289,21 @@ sub pagetemplate (@) {
 		$template->param(meta => join("\n", grep { (! $seen{$_}) && ($seen{$_}=1) } @{$metaheaders{$page}}));
 	}
 	if (exists $pagestate{$page}{meta}{title} && $template->query(name => "title")) {
-		eval q{use HTML::Entities};
 		$template->param(title => HTML::Entities::encode_numeric($pagestate{$page}{meta}{title}));
 		$template->param(title_overridden => 1);
 	}
 
-	if (exists $pagestate{$page}{meta}{enclosure}) {
-		$template->param(enclosure => HTML::Entities::encode_entities(IkiWiki::urlabs($pagestate{$page}{meta}{enclosure}, $config{url})));
-	}
-
-	foreach my $field (qw{authorurl}) {
-		eval q{use HTML::Entities};
-		$template->param($field => HTML::Entities::encode_entities($pagestate{$page}{meta}{$field}))
+	foreach my $field (qw{author authorurl permalink}) {
+		$template->param($field => $pagestate{$page}{meta}{$field})
 			if exists $pagestate{$page}{meta}{$field} && $template->query(name => $field);
 	}
 
 	foreach my $field (qw{permalink}) {
-		if (exists $pagestate{$page}{meta}{$field} && $template->query(name => $field)) {
-			eval q{use HTML::Entities};
-			$template->param($field => HTML::Entities::encode_entities(IkiWiki::urlabs($pagestate{$page}{meta}{$field}, $config{url})));
-		}
+		$template->param($field => IkiWiki::urlabs($pagestate{$page}{meta}{$field}, $config{url}))
+			if exists $pagestate{$page}{meta}{$field} && $template->query(name => $field);
 	}
 
-	foreach my $field (qw{description author}) {
-		eval q{use HTML::Entities};
+	foreach my $field (qw{description}) {
 		$template->param($field => HTML::Entities::encode_numeric($pagestate{$page}{meta}{$field}))
 			if exists $pagestate{$page}{meta}{$field} && $template->query(name => $field);
 	}
