@@ -7,10 +7,8 @@ use IkiWiki;
 use Monotone;
 use Date::Parse qw(str2time);
 use Date::Format qw(time2str);
-use URI::Escape q{uri_escape_utf8};
 
 my $sha1_pattern = qr/[0-9a-fA-F]{40}/; # pattern to validate sha1sums
-my $mtn_version = undef;
 
 sub import {
 	hook(type => "checkconfig", id => "monotone", call => \&checkconfig);
@@ -42,19 +40,20 @@ sub checkconfig () {
 		exec("mtn", "version") || error("mtn version failed to run");
 	}
 
+	my $version=undef;
 	while (<MTN>) {
 		if (/^monotone (\d+\.\d+)(?:(?:\.\d+){0,2}|dev)? /) {
-			$mtn_version=$1;
+			$version=$1;
 		}
 	}
 
 	close MTN || debug("mtn version exited $?");
 
-	if (!defined($mtn_version)) {
+	if (!defined($version)) {
 		error("Cannot determine monotone version");
 	}
-	if ($mtn_version < 0.38) {
-		error("Monotone version too old, is $mtn_version but required 0.38");
+	if ($version < 0.38) {
+		error("Monotone version too old, is $version but required 0.38");
 	}
 
 	if (defined $config{mtn_wrapper} && length $config{mtn_wrapper}) {
@@ -594,8 +593,7 @@ sub rcs_recentchanges ($) {
 				my $diffurl=$config{diffurl};
 				$diffurl=~s/\[\[r1\]\]/$parent/g;
 				$diffurl=~s/\[\[r2\]\]/$rev/g;
-				my $efile = uri_escape_utf8($file);
-				$diffurl=~s/\[\[file\]\]/$efile/g;
+				$diffurl=~s/\[\[file\]\]/$file/g;
 				push @pages, {
 					page => pagename($file),
 					diffurl => $diffurl,
@@ -664,11 +662,9 @@ sub rcs_getctime ($) {
 		     "--brief", $file) || error("mtn log $file failed to run");
 	}
 
-	my $prevRev;
 	my $firstRev;
 	while (<MTNLOG>) {
 		if (/^($sha1_pattern)/) {
-			$prevRev=$firstRev;
 			$firstRev=$1;
 		}
 	}
@@ -682,17 +678,6 @@ sub rcs_getctime ($) {
 	my $automator = Monotone->new();
 	$automator->open(undef, $config{mtnrootdir});
 
-	# mtn 0.48 has a bug that makes it list the creation of parent
-	# directories as last (first) log entry...  So when we're dealing
-	# with that version, let's check that the file we're looking for
-	# is actually part of the last (first) revision.  Otherwise, pick
-	# the one before (after) that one.
-	if ($mtn_version == 0.48) {
-		my $changes = [get_changed_files($automator, $firstRev)];
-		if (! exists {map { $_ => 1 } @$changes}->{$file}) {
-			$firstRev = $prevRev;
-		}
-	}
 	my $certs = [read_certs($automator, $firstRev)];
 
 	$automator->close();
@@ -718,55 +703,7 @@ sub rcs_getctime ($) {
 }
 
 sub rcs_getmtime ($) {
-	my $file=shift;
-
-	chdir $config{srcdir}
-	    or error("Cannot chdir to $config{srcdir}: $!");
-
-	my $child = open(MTNLOG, "-|");
-	if (! $child) {
-		exec("mtn", "log", "--root=$config{mtnrootdir}", "--no-graph",
-		     "--brief", $file) || error("mtn log $file failed to run");
-	}
-
-	my $lastRev = "";
-	while (<MTNLOG>) {
-		if (/^($sha1_pattern)/ && $lastRev eq "") {
-			$lastRev=$1;
-		}
-	}
-	close MTNLOG || debug("mtn log $file exited $?");
-
-	if (! defined $lastRev) {
-		debug "failed to parse mtn log for $file";
-		return 0;
-	}
-
-	my $automator = Monotone->new();
-	$automator->open(undef, $config{mtnrootdir});
-
-	my $certs = [read_certs($automator, $lastRev)];
-
-	$automator->close();
-
-	my $date;
-
-	foreach my $cert (@$certs) {
-		if ($cert->{signature} eq "ok" && $cert->{trust} eq "trusted") {
-			if ($cert->{name} eq "date") {
-				$date = $cert->{value};
-			}
-		}
-	}
-
-	if (! defined $date) {
-		debug "failed to find date cert for revision $lastRev when looking for creation time of $file";
-		return 0;
-	}
-
-	$date=str2time($date, 'UTC');
-	debug("found mtime ".localtime($date)." for $file");
-	return $date;
+	error "rcs_getmtime is not implemented for monotone\n"; # TODO
 }
 
 1
