@@ -8,7 +8,6 @@ use IkiWiki 3.00;
 
 sub import {
 	add_underlay("openid-selector");
-	add_underlay("jquery");
 	hook(type => "checkconfig", id => "openid", call => \&checkconfig);
 	hook(type => "getsetup", id => "openid", call => \&getsetup);
 	hook(type => "auth", id => "openid", call => \&auth);
@@ -100,10 +99,9 @@ sub formbuilder_setup (@) {
 	       IkiWiki::openiduser($session->param("name"))) {
 		$form->field(name => "openid_identifier", disabled => 1,
 			label => htmllink("", "", "ikiwiki/OpenID", noimageinline => 1),
-			value => "", 
-			size => 1, force => 1,
-			fieldset => "login",
-			comment => $session->param("name"));
+			value => $session->param("name"), 
+			size => length($session->param("name")), force => 1,
+			fieldset => "login");
 		$form->field(name => "email", type => "hidden");
 	}
 }
@@ -156,8 +154,8 @@ sub validate ($$$;$) {
 	$trust_root=$cgiurl if ! defined $trust_root;
 
 	my $check_url = $claimed_identity->check_url(
-		return_to => auto_upgrade_https($q, "$cgiurl?do=postsignin"),
-		trust_root => auto_upgrade_https($q, $trust_root),
+		return_to => "$cgiurl?do=postsignin",
+		trust_root => $trust_root,
 		delayed_return => 1,
 	);
 	# Redirect the user to the OpenID server, which will
@@ -231,7 +229,6 @@ sub getobj ($$) {
 	my $q=shift;
 	my $session=shift;
 
-	eval q{use Net::INET6Glue::INET_is_INET6}; # may not be available
 	eval q{use Net::OpenID::Consumer};
 	error($@) if $@;
 
@@ -241,7 +238,7 @@ sub getobj ($$) {
 		$ua=LWPx::ParanoidAgent->new;
 	}
 	else {
-		$ua=useragent();
+	        $ua=LWP::UserAgent->new;
 	}
 
 	# Store the secret in the session.
@@ -258,19 +255,10 @@ sub getobj ($$) {
 		ua => $ua,
 		args => $q,
 		consumer_secret => sub { return shift()+$secret },
-		required_root => auto_upgrade_https($q, $cgiurl),
+		required_root => $cgiurl,
 	);
 }
 
-sub auto_upgrade_https {
-	my $q=shift;
-	my $url=shift;
-	if ($q->https()) {
-		$url=~s/^http:/https:/i;
-	}
-	return $url;
-}
-
 sub load_openid_module {
 	# Give up if module is unavailable to avoid needing to depend on it.
 	eval q{use Net::OpenID::Consumer};
