@@ -13,7 +13,7 @@ sub import {
 	hook(type => "needsbuild", id => "pinger", call => \&needsbuild);
 	hook(type => "preprocess", id => "ping", call => \&preprocess);
 	hook(type => "delete", id => "pinger", call => \&ping);
-	hook(type => "rendered", id => "pinger", call => \&ping);
+	hook(type => "change", id => "pinger", call => \&ping);
 }
 
 sub getsetup () {
@@ -67,8 +67,6 @@ sub ping {
 	if (! $pinged && %pages) {
 		$pinged=1;
 		
-		eval q{use Net::INET6Glue::INET_is_INET6}; # may not be available
-		
 		my $ua;
 		eval q{use LWPx::ParanoidAgent};
 		if (!$@) {
@@ -80,7 +78,7 @@ sub ping {
 				debug(gettext("LWP not found, not pinging"));
 				return;
 			}
-			$ua=useragent();
+			$ua=LWP::UserAgent->new;
 		}
 		$ua->timeout($config{pinger_timeout} || 15);
 		
