@@ -23,6 +23,7 @@ use File::Copy;
 use File::Spec;
 use File::Temp;
 use Memoize;
+use UNIVERSAL;
 
 my ($master_language_code, $master_language_name);
 my %translations;
@@ -30,7 +31,6 @@ my @origneedsbuild;
 my %origsubs;
 my @slavelanguages; # language codes ordered as in config po_slave_languages
 my %slavelanguages; # language code to name lookup
-my $language_code_pattern = '[a-zA-Z]+(?:_[a-zA-Z]+)?';
 
 memoize("istranslatable");
 memoize("_istranslation");
@@ -38,8 +38,7 @@ memoize("percenttranslated");
 
 sub import {
 	hook(type => "getsetup", id => "po", call => \&getsetup);
-	hook(type => "checkconfig", id => "po", call => \&checkconfig,
-		last => 1);
+	hook(type => "checkconfig", id => "po", call => \&checkconfig);
 	hook(type => "needsbuild", id => "po", call => \&needsbuild);
 	hook(type => "scan", id => "po", call => \&scan, last => 1);
 	hook(type => "filter", id => "po", call => \&filter);
@@ -47,7 +46,7 @@ sub import {
 	hook(type => "pagetemplate", id => "po", call => \&pagetemplate, last => 1);
 	hook(type => "rename", id => "po", call => \&renamepages, first => 1);
 	hook(type => "delete", id => "po", call => \&mydelete);
-	hook(type => "rendered", id => "po", call => \&rendered);
+	hook(type => "change", id => "po", call => \&change);
 	hook(type => "checkcontent", id => "po", call => \&checkcontent);
 	hook(type => "canremove", id => "po", call => \&canremove);
 	hook(type => "canrename", id => "po", call => \&canrename);
@@ -66,11 +65,8 @@ sub import {
 		inject(name => "IkiWiki::urlto", call => \&myurlto);
 		$origsubs{'cgiurl'}=\&IkiWiki::cgiurl;
 		inject(name => "IkiWiki::cgiurl", call => \&mycgiurl);
-		if (IkiWiki->can('rootpage')) {
-			$origsubs{'rootpage'}=\&IkiWiki::rootpage;
-			inject(name => "IkiWiki::rootpage", call => \&myrootpage)
-				if defined $origsubs{'rootpage'};
-		}
+		$origsubs{'rootpage'}=\&IkiWiki::rootpage;
+		inject(name => "IkiWiki::rootpage", call => \&myrootpage);
 		$origsubs{'isselflink'}=\&IkiWiki::isselflink;
 		inject(name => "IkiWiki::isselflink", call => \&myisselflink);
 	}
@@ -342,13 +338,6 @@ sub pagetemplate (@) {
 	if ($template->query(name => "istranslatable")) {
 		$template->param(istranslatable => istranslatable($page));
 	}
-	my $lang_code = istranslation($page) ? lang($page) : $master_language_code;
-	if ($template->query(name => "lang_code")) {
-		$template->param(lang_code => $lang_code);
-	}
-	if ($template->query(name => "lang_name")) {
-		$template->param(lang_name => languagename($lang_code));
-	}
 	if ($template->query(name => "HOMEPAGEURL")) {
 		$template->param(homepageurl => homepageurl($page));
 	}
@@ -427,7 +416,7 @@ sub mydelete (@) {
 	map { deletetranslations($_) } grep istranslatablefile($_), @deleted;
 }
 
-sub rendered (@) {
+sub change (@) {
 	my @rendered=@_;
 
 	my $updated_po_files=0;
@@ -631,24 +620,20 @@ sub mybeautify_urlpath ($) {
 	return $res;
 }
 
-sub mytargetpage ($$;$) {
+sub mytargetpage ($$) {
 	my $page=shift;
 	my $ext=shift;
-	my $filename=shift;
 
 	if (istranslation($page) || istranslatable($page)) {
 		my ($masterpage, $lang) = (masterpage($page), lang($page));
-		if (defined $filename) {
-			return $masterpage . "/" . $filename . "." . $lang . "." . $ext;
-		}
-		elsif (! $config{usedirs} || $masterpage eq 'index') {
+		if (! $config{usedirs} || $masterpage eq 'index') {
 			return $masterpage . "." . $lang . "." . $ext;
 		}
 		else {
 			return $masterpage . "/index." . $lang . "." . $ext;
 		}
 	}
-	return $origsubs{'targetpage'}->($page, $ext, $filename);
+	return $origsubs{'targetpage'}->($page, $ext);
 }
 
 sub myurlto ($;$$) {
@@ -818,7 +803,7 @@ sub _istranslation ($) {
 			 && pagetype($file) eq 'po';
 	return 0 if $file =~ /\.pot$/;
 
-	my ($masterpage, $lang) = ($page =~ /(.*)[.]($language_code_pattern)$/);
+	my ($masterpage, $lang) = ($page =~ /(.*)[.]([a-z]{2})$/);
 	return 0 unless defined $masterpage && defined $lang
 			 && length $masterpage && length $lang
 			 && defined $pagesources{$masterpage}
@@ -860,7 +845,7 @@ sub lang ($) {
 sub islanguagecode ($) {
 	my $code=shift;
 
-	return $code =~ /^$language_code_pattern$/;
+	return $code =~ /^[a-z]{2}$/;
 }
 
 sub otherlanguage_page ($$) {
@@ -1102,7 +1087,7 @@ sub deletetranslations ($) {
 			IkiWiki::rcs_remove($_);
 		}
 		else {
-			IkiWiki::prune("$config{srcdir}/$_", $config{srcdir});
+			IkiWiki::prune("$config{srcdir}/$_");
 		}
 	} @todelete;
 
@@ -1252,7 +1237,6 @@ sub po4a_options($) {
 		# how to disable options is not consistent across po4a modules
 		$options{includessi} = '';
 		$options{includeexternal} = 0;
-		$options{ontagerror} = 'warn';
 	}
 	elsif ($pagetype eq 'mdwn') {
 		$options{markdown} = 1;
@@ -1267,7 +1251,7 @@ sub po4a_options($) {
 sub splitlangpair ($) {
 	my $pair=shift;
 
-	my ($code, $name) = ( $pair =~ /^($language_code_pattern)\|(.+)$/ );
+	my ($code, $name) = ( $pair =~ /^([a-z]{2})\|(.+)$/ );
 	if (! defined $code || ! defined $name ||
 	    ! length $code || ! length $name) {
 		# not a fatal error to avoid breaking if used with web setup
