@@ -16,8 +16,6 @@ sub import {
 	hook(type => "sessioncgi", id => "recentchanges", call => \&sessioncgi);
 	# Load goto to fix up links from recentchanges
 	IkiWiki::loadplugin("goto");
-	# ... and transient as somewhere to put our internal pages
-	IkiWiki::loadplugin("transient");
 }
 
 sub getsetup () {
@@ -58,7 +56,7 @@ sub refresh ($) {
 	# delete old and excess changes
 	foreach my $page (keys %pagesources) {
 		if ($pagesources{$page} =~ /\._change$/ && ! $seen{$page}) {
-			unlink($IkiWiki::Plugin::transient::transientdir.'/'.$pagesources{$page}) || unlink($config{srcdir}.'/'.$pagesources{$page});
+			unlink($config{srcdir}.'/'.$pagesources{$page});
 		}
 	}
 }
@@ -165,7 +163,6 @@ sub store ($$$) {
 	# Limit pages to first 10, and add links to the changed pages.
 	my $is_excess = exists $change->{pages}[10];
 	delete @{$change->{pages}}[10 .. @{$change->{pages}}] if $is_excess;
-	my $has_diffurl=0;
 	$change->{pages} = [
 		map {
 			if (length $config{cgiurl}) {
@@ -181,9 +178,6 @@ sub store ($$$) {
 			else {
 				$_->{link} = pagetitle($_->{page});
 			}
-			if (defined $_->{diffurl} && length($_->{diffurl})) {
-				$has_diffurl=1;
-			}
 
 			$_;
 		} @{$change->{pages}}
@@ -231,8 +225,6 @@ sub store ($$$) {
 		wikiname => $config{wikiname},
 	);
 	
-	$template->param(has_diffurl => 1) if $has_diffurl;
-
 	$template->param(permalink => urlto($config{recentchangespage})."#change-".titlepage($change->{rev}))
 		if exists $config{url};
 	
@@ -242,8 +234,8 @@ sub store ($$$) {
 	});
 
 	my $file=$page."._change";
-	writefile($file, $IkiWiki::Plugin::transient::transientdir, $template->output);
-	utime $change->{when}, $change->{when}, $IkiWiki::Plugin::transient::transientdir.'/'.$file;
+	writefile($file, $config{srcdir}, $template->output);
+	utime $change->{when}, $change->{when}, "$config{srcdir}/$file";
 
 	return $page;
 }
