@@ -5,7 +5,6 @@ use warnings;
 use strict;
 use IkiWiki;
 use POSIX qw(setlocale LC_CTYPE);
-use URI::Escape q{uri_escape_utf8};
 
 sub import {
 	hook(type => "checkconfig", id => "svn", call => \&checkconfig);
@@ -123,8 +122,10 @@ sub svn_info ($$) {
 }
 
 sub rcs_update () {
-	if (system("svn", "update", "--quiet", $config{srcdir}) != 0) {
-		warn("svn update failed\n");
+	if (-d "$config{srcdir}/.svn") {
+		if (system("svn", "update", "--quiet", $config{srcdir}) != 0) {
+			warn("svn update failed\n");
+		}
 	}
 }
 
@@ -135,10 +136,12 @@ sub rcs_prepedit ($) {
 	# The file is relative to the srcdir.
 	my $file=shift;
 	
-	# For subversion, return the revision of the file when
-	# editing begins.
-	my $rev=svn_info("Revision", "$config{srcdir}/$file");
-	return defined $rev ? $rev : "";
+	if (-d "$config{srcdir}/.svn") {
+		# For subversion, return the revision of the file when
+		# editing begins.
+		my $rev=svn_info("Revision", "$config{srcdir}/$file");
+		return defined $rev ? $rev : "";
+	}
 }
 
 sub commitmessage (@) {
@@ -165,30 +168,31 @@ sub rcs_commit (@) {
 	# The file is relative to the srcdir.
 	my %params=@_;
 
-	# Check to see if the page has been changed by someone
-	# else since rcs_prepedit was called.
-	my ($oldrev)=$params{token}=~/^([0-9]+)$/; # untaint
-	my $rev=svn_info("Revision", "$config{srcdir}/$params{file}");
-	if (defined $rev && defined $oldrev && $rev != $oldrev) {
-		# Merge their changes into the file that we've
-		# changed.
-		if (system("svn", "merge", "--quiet", "-r$oldrev:$rev",
-		           "$config{srcdir}/$params{file}", "$config{srcdir}/$params{file}") != 0) {
-			warn("svn merge -r$oldrev:$rev failed\n");
+	if (-d "$config{srcdir}/.svn") {
+		# Check to see if the page has been changed by someone
+		# else since rcs_prepedit was called.
+		my ($oldrev)=$params{token}=~/^([0-9]+)$/; # untaint
+		my $rev=svn_info("Revision", "$config{srcdir}/$params{file}");
+		if (defined $rev && defined $oldrev && $rev != $oldrev) {
+			# Merge their changes into the file that we've
+			# changed.
+			if (system("svn", "merge", "--quiet", "-r$oldrev:$rev",
+			           "$config{srcdir}/$params{file}", "$config{srcdir}/$params{file}") != 0) {
+				warn("svn merge -r$oldrev:$rev failed\n");
+			}
+		}
+
+		if (system("svn", "commit", "--quiet", 
+		           "--encoding", "UTF-8", "-m",
+		           IkiWiki::possibly_foolish_untaint(commitmessage(%params)),
+			   $config{srcdir}) != 0) {
+			my $conflict=readfile("$config{srcdir}/$params{file}");
+			if (system("svn", "revert", "--quiet", "$config{srcdir}/$params{file}") != 0) {
+				warn("svn revert failed\n");
+			}
+			return $conflict;
 		}
 	}
-
-	if (system("svn", "commit", "--quiet", 
-	           "--encoding", "UTF-8", "-m",
-	           IkiWiki::possibly_foolish_untaint(commitmessage(%params)),
-		   $config{srcdir}) != 0) {
-		my $conflict=readfile("$config{srcdir}/$params{file}");
-		if (system("svn", "revert", "--quiet", "$config{srcdir}/$params{file}") != 0) {
-			warn("svn revert failed\n");
-		}
-		return $conflict;
-	}
-
 	return undef # success
 }
 
@@ -211,8 +215,16 @@ sub rcs_add ($) {
 	# filename is relative to the root of the srcdir
 	my $file=shift;
 
-	if (system("svn", "add", "--parents", "--quiet", "$config{srcdir}/$file") != 0) {
-		warn("svn add failed\n");
+	if (-d "$config{srcdir}/.svn") {
+		my $parent=IkiWiki::dirname($file);
+		while (! -d "$config{srcdir}/$parent/.svn") {
+			$file=$parent;
+			$parent=IkiWiki::dirname($file);
+		}
+		
+		if (system("svn", "add", "--quiet", "$config{srcdir}/$file") != 0) {
+			warn("svn add failed\n");
+		}
 	}
 }
 
@@ -220,8 +232,10 @@ sub rcs_remove ($) {
 	# filename is relative to the root of the srcdir
 	my $file=shift;
 
-	if (system("svn", "rm", "--force", "--quiet", "$config{srcdir}/$file") != 0) {
-		warn("svn rm failed\n");
+	if (-d "$config{srcdir}/.svn") {
+		if (system("svn", "rm", "--force", "--quiet", "$config{srcdir}/$file") != 0) {
+			warn("svn rm failed\n");
+		}
 	}
 }
 
@@ -229,9 +243,22 @@ sub rcs_rename ($$) {
 	# filenames relative to the root of the srcdir
 	my ($src, $dest)=@_;
 	
-	if (system("svn", "mv", "--parents", "--force", "--quiet", 
-	    "$config{srcdir}/$src", "$config{srcdir}/$dest") != 0) {
-		warn("svn rename failed\n");
+	if (-d "$config{srcdir}/.svn") {
+		# Add parent directory for $dest
+		my $parent=IkiWiki::dirname($dest);
+		if (! -d "$config{srcdir}/$parent/.svn") {
+			while (! -d "$config{srcdir}/$parent/.svn") {
+				$parent=IkiWiki::dirname($dest);
+			}
+			if (system("svn", "add", "--quiet", "$config{srcdir}/$parent") != 0) {
+				warn("svn add $parent failed\n");
+			}
+		}
+
+		if (system("svn", "mv", "--force", "--quiet", 
+		    "$config{srcdir}/$src", "$config{srcdir}/$dest") != 0) {
+			warn("svn rename failed\n");
+		}
 	}
 }
 
@@ -239,6 +266,8 @@ sub rcs_recentchanges ($) {
 	my $num=shift;
 	my @ret;
 	
+	return unless -d "$config{srcdir}/.svn";
+
 	eval q{
 		use Date::Parse;
 		use XML::SAX;
@@ -293,8 +322,7 @@ sub rcs_recentchanges ($) {
 			}
 
 			my $diffurl=defined $config{diffurl} ? $config{diffurl} : "";
-			my $efile = uri_escape_utf8($file);
-			$diffurl=~s/\[\[file\]\]/$efile/g;
+			$diffurl=~s/\[\[file\]\]/$file/g;
 			$diffurl=~s/\[\[r1\]\]/$rev - 1/eg;
 			$diffurl=~s/\[\[r2\]\]/$rev/g;
 
